@@ -26,7 +26,7 @@ keys::keys(QWidget *parent) :
                                 <<tr("L1")<<tr("R1")<<tr("L2")<<tr("R2")<<tr("Quit")
                                 <<tr("Up+Left")<<tr("Up+Right")
                                 <<tr("Down+Left")<<tr("Down+Right")
-                                <<tr("Save")<<tr("Load")<<tr("slot+")<<tr("slot-");
+                                <<tr("Save")<<tr("Load")<<tr("slot+")<<tr("slot-")<<tr("Change disc");
 
     this->setWindowTitle(tr("Configure keys"));
     this->setWindowFlags(this->windowFlags() | Qt::Window);
