@@ -85,6 +85,13 @@ void MainWindow::get_roms()
             icon = QIcon(QString("%1.png").arg(fileInfo.filePath()));
         else if (QFile::exists(QString("%1png").arg(fileInfo.filePath().replace(fileInfo.suffix(), ""))))
             icon = QIcon(QString("%1png").arg(fileInfo.filePath().replace(fileInfo.suffix(), "")));
+        else if (QString::compare(fileInfo.suffix(), "pbp", Qt::CaseInsensitive) == 0){
+            QByteArray iconData = get_pbp_icon(fileInfo.filePath());
+            if (iconData.size() > 0){
+                QImage image = QImage::fromData(iconData);
+                icon = QIcon(QPixmap::fromImage(image));
+            }
+        }
         ui->listWidget->addItem(new QListWidgetItem(icon, fileInfo.fileName()));
 
         rom->FilePath = fileInfo.absoluteFilePath();
@@ -352,3 +359,47 @@ int MainWindow::count_save_states(QString name)
     res = list.count();
     return res;
 }
+
+QByteArray MainWindow::get_pbp_icon(QString filename)
+{
+    QByteArray res;
+
+    QFile inFile(filename);
+    if (!inFile.open(QIODevice::ReadOnly))
+        return res;
+
+    QDataStream inStream( &inFile );
+
+    char signature[4];
+    inStream.readRawData((char *)(signature), sizeof(signature));
+    if ((signature[0] != 0x00) || (signature[1] != 0x50) || (signature[2] != 0x42) || (signature[3] != 0x50)) {
+        inFile.close();
+        return res;
+    }
+
+    unsigned int version;
+    inStream >> version;
+
+    uint32_t offset[8];
+    inStream.readRawData((char *)(offset), sizeof(offset));
+
+    offset[8] = inFile.size();
+
+    int iconSize = offset[2] - offset[1];
+    int iconOffset = offset[1] - offset[0];
+
+    char buffer[iconSize];
+    if (inStream.skipRawData(iconOffset) != iconOffset) {
+        inFile.close();
+        return res;
+    }
+
+    if (inStream.readRawData(buffer, iconSize) != iconSize) {
+        inFile.close();
+        return res;
+    }
+
+    res = QByteArray(buffer, iconSize);
+    inFile.close();
+    return res;
+}
