@@ -13,7 +13,7 @@ class MemoryCardSelect : public QDialog
     Q_OBJECT
 
 public:
-    explicit MemoryCardSelect(QWidget *parent = 0);
+    explicit MemoryCardSelect(QWidget *parent = 0, QString selected="");
     ~MemoryCardSelect();
     QString Selected();
 
