@@ -1,6 +1,7 @@
 #include "options.h"
 #include "ui_options.h"
 #include "memorycardselect.h"
+#include "accelerometerconfig.h"
 
 QStringList current_config=QStringList();
 QString current_core="";
@@ -13,9 +14,11 @@ options::options(QWidget *parent) :
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
     this->setWindowFlags(this->windowFlags() | Qt::Window);
-    connect (ui->checkBox_2,SIGNAL(clicked()),this,SLOT(psx4m_hwa_block()));
+    connect(ui->checkBox_2,SIGNAL(clicked()),this,SLOT(psx4m_hwa_block()));
+    connect(ui->checkBox_9,SIGNAL(toggled(bool)),this,SLOT(accel_toggled(bool)));
     connect(ui->pbnMemoryCard1, SIGNAL(clicked()),this,SLOT(memory_card_1()));
     connect(ui->pbnMemoryCard2, SIGNAL(clicked()),this,SLOT(memory_card_2()));
+    connect(ui->pbnConfigAccel, SIGNAL(clicked()), this, SLOT(config_accel()));
 
     QDir dir( bios_path);
     dir.setFilter(QDir::Files);
@@ -80,9 +83,10 @@ void options::load_cfg(){
     configs << "pcsx-threadedspu" << "pcsx-hwa" << "pcsx-bios" << "pcsx-frameskip";
     configs << "accel" << "cdda" << "xa" << "rcnt" << "sio" << "spuirq" << "vsync" << "fsaa" << "pcsx-fullscreen";
     configs << "pcsx-fps" << "pcsx-cpu" << "pcsx-nofl" << "mcd1" << "mcd2" << "spu_reverb" << "spu_interpolation";
-    configs << "region";
+    configs << "region" << "analog" << "accel_sens" << "accel_y_def" << "accel_max" << "displayon";
 
     ui->comboBox_5->setCurrentIndex(0);
+    ui->checkBox_9->setChecked(false);
     ui->checkBox_4->setChecked(false);
     ui->checkBox_18->setChecked(false);
     ui->checkBox_19->setChecked(false);
@@ -90,6 +94,11 @@ void options::load_cfg(){
     ui->cmbInterpolation->setCurrentIndex(0);
     ui->cmbRegion->setCurrentIndex(0);
 
+    ui->chkDisplayOn->setChecked(false);
+    ui->numSens->setValue(150);
+    ui->numYDef->setValue(500);
+    ui->numMaxValue->setValue(500);
+
     if (QFile::exists(path)){
         QFile file(path);
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
@@ -137,18 +146,18 @@ void options::load_cfg(){
                       if (value=="1")ui->checkBox_3->setChecked(true);else ui->checkBox_3->setChecked(false);
                       break;
                  case 10:// pcsx-hwa
-                     if (ui->comboBox_5->findText(value)!=1)
+                     if (ui->comboBox_5->findText(value)!=-1)
                          ui->comboBox_5->setCurrentIndex(ui->comboBox_5->findText(value));
                       break;
                  case 11:// pcsx-bios
-                      if (value=="1")ui->checkBox_5->setChecked(true);else ui->checkBox_5->setChecked(false);
+                      if (value=="1")ui->checkBox_5->setChecked(true);else ui->checkBox_5->setChecked(false);                      
                       break;
                  case 12:// pcsx-frameskip
                       if (ui->comboBox_3->findText(value)!=-1)
                           ui->comboBox_3->setCurrentIndex(ui->comboBox_3->findText(value));
                       break;
                  case 13:
-                      if (value=="1")ui->checkBox_9->setChecked(true);else ui->checkBox_9->setChecked(false);
+                      if (value=="1")ui->checkBox_9->setChecked(true);else ui->checkBox_9->setChecked(false);                      
                       break;
                  case 14:
                       if (value=="1")ui->checkBox_10->setChecked(true);else ui->checkBox_10->setChecked(false);
@@ -206,6 +215,21 @@ void options::load_cfg(){
                      if (ui->cmbRegion->findText(value)!=1)
                          ui->cmbRegion->setCurrentIndex(ui->cmbRegion->findText(value));
                      break;
+                 case 30:
+                     if (value=="1")ui->chkAnalog->setChecked(true);else ui->chkAnalog->setChecked(false);
+                     break;
+                 case 31:
+                     ui->numSens->setValue(value.toInt());
+                     break;
+                 case 32:
+                     ui->numYDef->setValue(value.toInt());
+                     break;
+                 case 33:
+                     ui->numMaxValue->setValue(value.toInt());
+                     break;
+                 case 34:
+                     if (value=="1")ui->chkDisplayOn->setChecked(true);else ui->chkDisplayOn->setChecked(false);
+                     break;
                  default:
                       qDebug(QString("Undefined setting:%1 = %2").arg(line.at(0)).arg(value).toAscii());
                       break;
@@ -215,6 +239,7 @@ void options::load_cfg(){
 
              // checking
              psx4m_hwa_block();
+             accel_toggled(ui->checkBox_9->isChecked());
 
              if (!ui->comboBox_4->currentIndex()>-1)ui->comboBox_4->setCurrentIndex(0);
 
@@ -233,7 +258,7 @@ void options::createCfg(){
     if (ui->checkBox_12->isChecked())current_config<<"-sio";
     if (ui->checkBox_13->isChecked())current_config<<"-spuirq";
     if (ui->checkBox_14->isChecked())current_config<<"-rcnt";
-    if (ui->checkBox_15->isChecked())current_config<<"-vsync";
+    if (ui->checkBox_15->isChecked())current_config<<"-vsync";    
     current_config<<"-mcd1"<<m_MemoryCard1;
     current_config<<"-mcd2"<<m_MemoryCard2;
 
@@ -241,6 +266,12 @@ void options::createCfg(){
     {
         current_core="pcsx";
 
+        if (ui->chkDisplayOn->isChecked())current_config<<"-displayon";
+        if (ui->chkAnalog->isChecked())current_config<<"-analog";
+        current_config<<"-sens"<<QString::number(ui->numSens->value());
+        current_config<<"-ydef"<<QString::number(ui->numYDef->value());
+        current_config<<"-max"<<QString::number(ui->numMaxValue->value());
+
         if (ui->checkBox_3->isChecked())current_config<<"-sputhreaded";
         if (ui->comboBox_5->currentText()=="oldgpu")current_config<<"-oldgpu";
         else if (ui->comboBox_5->currentText()=="gpu-gles")current_config<<"-gles";
@@ -335,7 +366,12 @@ void options::save_cfg(){
                    "mcd2=%27\n" \
                    "spu_reverb=%28\n" \
                    "spu_interpolation=%29\n" \
-                   "region=%30\n")
+                   "region=%30\n" \
+                   "analog=%31\n" \
+                   "accel_sens=%32\n" \
+                   "accel_y_def=%33\n" \
+                   "accel_max=%34\n" \
+                   "displayon=%35\n")
             .arg(ui->radioButton_2->isChecked()?"1":"0")
             .arg(ui->checkBox->isChecked()?"1":"0")
             .arg(ui->comboBox_4->currentText())
@@ -365,7 +401,12 @@ void options::save_cfg(){
             .arg(m_MemoryCard2)
             .arg(ui->chkReverb->isChecked()?"1":"0")
             .arg(ui->cmbInterpolation->currentText())
-            .arg(ui->cmbRegion->currentText());
+            .arg(ui->cmbRegion->currentText())
+            .arg(ui->chkAnalog->isChecked()?"1":"0")
+            .arg(ui->numSens->value())
+            .arg(ui->numYDef->value())
+            .arg(ui->numMaxValue->value())
+            .arg(ui->chkDisplayOn->isChecked()?"1":"0");
 
     QFile file(path);
     QFileInfo pathInfo(path);
@@ -456,3 +497,24 @@ void options::show()
     m_Loop->exec();
 
 }
+
+void options::accel_toggled(bool toggled)
+{
+    ui->chkAnalog->setEnabled(toggled);
+    ui->numSens->setEnabled(toggled);
+    ui->numYDef->setEnabled(toggled);
+    ui->numMaxValue->setEnabled(toggled);
+    ui->pbnConfigAccel->setEnabled(toggled);
+}
+
+void options::config_accel()
+{
+    AccelerometerConfig* dlg = new AccelerometerConfig(this, ui->numSens->value(), ui->numYDef->value(), ui->numMaxValue->value());
+    dlg->show();
+
+    ui->numSens->setValue(dlg->GetSens());
+    ui->numYDef->setValue(dlg->GetYDef());
+    ui->numMaxValue->setValue(dlg->GetMaxValue());
+
+    delete dlg;
+}
