@@ -26,6 +26,8 @@ public slots:
     void memory_card_1();
     void memory_card_2();
     void show();
+    void accel_toggled(bool toggled);
+    void config_accel();
 
 protected:
     void hideEvent(QHideEvent *);
